@@ -1,18 +1,18 @@
 package Mastodon::Entity::Application;
 
-our $VERSION = '0.008';
-
 use strict;
 use warnings;
 
+our $VERSION = '0.009';
+
 use Moo;
 with 'Mastodon::Role::Entity';
 
-use Types::Standard qw( Str );
+use Types::Standard qw( Str Maybe );
 use Mastodon::Types qw( URI );
 
-has name     => ( is => 'ro', isa => Str, required => 1 );
-has website  => ( is => 'ro', isa => Maybe[URI], coerce => 1);
+has name     => ( is => 'ro', isa => Str, );
+has website  => ( is => 'ro', isa => Maybe[URI], coerce => 1, required => 1,);
 
 1;
 
