@@ -1,20 +1,20 @@
 package Mastodon::Entity::Card;
 
-our $VERSION = '0.008';
-
 use strict;
 use warnings;
 
+our $VERSION = '0.009';
+
 use Moo;
 with 'Mastodon::Role::Entity';
 
 use Types::Standard qw( Any Str );
 use Mastodon::Types qw( URI );
 
-has description => ( is => 'ro', isa => Str, required => 1 );
-has image       => ( is => 'ro', isa => Any ); # What type of data is this?
-has title       => ( is => 'ro', isa => Str );
-has url         => ( is => 'ro', isa => URI, coerce => 1, required => 1);
+has description => ( is => 'ro', isa => Str, required => 1, );
+has image       => ( is => 'ro', isa => Any, ); # What type of data is this?
+has title       => ( is => 'ro', isa => Str, );
+has url         => ( is => 'ro', isa => URI, coerce => 1, required => 1, );
 
 1;
 
