@@ -1,16 +1,16 @@
 package Mastodon::Entity::Error;
 
-our $VERSION = '0.008';
-
 use strict;
 use warnings;
 
+our $VERSION = '0.009';
+
 use Moo;
 with 'Mastodon::Role::Entity';
 
 use Types::Standard qw( Str );
 
-has error => ( is => 'ro', isa => Str, required => 1 );
+has error => ( is => 'ro', isa => Str, required => 1, );
 
 1;
 
