@@ -1,17 +1,17 @@
 package Mastodon::Entity::Report;
 
-our $VERSION = '0.008';
-
 use strict;
 use warnings;
 
+our $VERSION = '0.009';
+
 use Moo;
 with 'Mastodon::Role::Entity';
 
 use Types::Standard qw( Int Bool );
 
-has id           => ( is => 'ro', isa => Int );
-has action_taken => ( is => 'ro', isa => Bool, required => 1 );
+has id           => ( is => 'ro', isa => Int, );
+has action_taken => ( is => 'ro', isa => Bool, required => 1, );
 
 1;
 
