@@ -1,10 +1,10 @@
 package Mastodon::Types;
 
-our $VERSION = '0.008';
-
 use strict;
 use warnings;
 
+our $VERSION = '0.009';
+
 use Type::Library -base;
 
 use Type::Utils -all;
@@ -14,14 +14,15 @@ use Types::Path::Tiny qw( File to_File);
 use URI;
 use DateTime;
 use MIME::Base64;
+use Class::Load qw( load_class );
 
 duck_type 'UserAgent', [qw( get post delete )];
 
 class_type 'URI', { class => 'URI' };
 
 coerce 'URI', from Str, via {
-  s%^/+%%g;
-  my $uri = URI->new((m%^https?://% ? '' : 'https://') . $_);
+  s{^/+}{}g;
+  my $uri = URI->new((m{^https?://} ? q{} : 'https://') . $_);
   $uri->scheme('https') unless $uri->scheme;
   return $uri;
 };
@@ -49,7 +50,7 @@ coerce 'DateTime',
 declare 'Acct', as Str;
 
 declare 'Image',
-  as Str, where { m%^data:image/(png|jpeg);base64,[a-zA-Z0-9/+=\n]+$% };
+  as Str, where { m{^data:image/(?:png|jpeg);base64,[a-zA-Z0-9/+=\n]+$} };
 
 coerce File, from Str, via {
   require Path::Tiny;
@@ -78,7 +79,7 @@ my @entities = qw(
 foreach my $name (@entities) {
   class_type $name, { class => "Mastodon::Entity::$name" };
   coerce $name, from HashRef, via {
-    eval "require Mastodon::Entity::$name";
+    load_class "Mastodon::Entity::$name";
     "Mastodon::Entity::$name"->new($_);
   };
 }
@@ -103,7 +104,7 @@ coerce 'Entity',
       use Try::Tiny;
       foreach my $name (@entities) {
         $entity = try {
-          eval "require Mastodon::Entity::$name;";
+          load_class "Mastodon::Entity::$name";
           "Mastodon::Entity::$name"->new($hash);
         };
         last if defined $entity;
